@@ -6,6 +6,7 @@ import imp
 import os
 import re
 import sys
+import time
 import types
 import unittest
 import weakref
@@ -49,6 +50,15 @@ class CommonTestCase(unittest.TestCase):
         """
         raise NotImplementedError
 
+    @property
+    def test_name(self):
+        if hasattr(self, 'jsFile'):
+            return os.path.basename(self.jsFile)
+        else:
+            return '%s.py %s.%s' % (self.__class__.__module__,
+                                    self.__class__.__name__,
+                                    self._testMethodName)
+
     def set_up_test_page(self, emulator, url="test.html", permissions=None):
         emulator.set_context("content")
         url = emulator.absolute_url(url)
@@ -112,15 +122,20 @@ class MarionetteTestCase(CommonTestCase):
                                   methodName=testname,
                                   filepath=filepath,
                                   testvars=testvars))
+
     def setUp(self):
         CommonTestCase.setUp(self)
+        self.start_time = time.time()
+        self.marionette.test_name = self.test_name
         self.marionette.execute_script("log('TEST-START: %s:%s')" % 
                                        (self.filepath.replace('\\', '\\\\'), self.methodName))
 
     def tearDown(self):
+        self.duration = time.time() - self.start_time
         self.marionette.set_context("content")
         self.marionette.execute_script("log('TEST-END: %s:%s')" % 
                                        (self.filepath.replace('\\', '\\\\'), self.methodName))
+        self.marionette.test_name = None
         CommonTestCase.tearDown(self)
 
     def get_new_emulator(self):
@@ -159,6 +174,7 @@ class MarionetteJSTestCase(CommonTestCase):
     def runTest(self):
         if self.marionette.session is None:
             self.marionette.start_session()
+        self.marionette.test_name = os.path.basename(self.jsFile)
         self.marionette.execute_script("log('TEST-START: %s');" % self.jsFile.replace('\\', '\\\\'))
 
         f = open(self.jsFile, 'r')
@@ -206,7 +222,8 @@ class MarionetteJSTestCase(CommonTestCase):
                 for failure in results['failures']:
                     diag = "" if failure.get('diag') is None else "| %s " % failure['diag']
                     name = "got false, expected true" if failure.get('name') is None else failure['name']
-                    fails.append('TEST-UNEXPECTED-FAIL %s| %s' % (diag, name))
+                    fails.append('TEST-UNEXPECTED-FAIL | %s %s| %s' %
+                                 (os.path.basename(self.jsFile), diag, name))
                 self.assertEqual(0, results['failed'],
                                  '%d tests failed:\n%s' % (results['failed'], '\n'.join(fails)))
 
@@ -223,6 +240,4 @@ class MarionetteJSTestCase(CommonTestCase):
                 raise
 
         self.marionette.execute_script("log('TEST-END: %s');" % self.jsFile.replace('\\', '\\\\'))
-
-
-
+        self.marionette.test_name = None
